#! /usr/bin/env python
#
# a script to anaylze impedances
# 
from pylab import *
from numpy import loadtxt

# * * * * * * * * * *#
# load data
afilename = "../data/EOM24A.TXT"
pfilename = "../data/EOM24P.TXT"
A_filename = "../data/NEW24.txt"

A = loadtxt(afilename)
P = loadtxt(pfilename)
T = loadtxt(A_filename)

f = A[:,0]

# derive impedance
M = 10**(A[:,1]/20) * exp(2* 1j * pi/360. * P[:,1])
Z = 50 * M /(2-M)

# derive return loss
R = (Z - 50)/(Z+50)

# plot figure
figure(1009)
subplot(211)
title("RF characteristic of 24 MHz input")
semilogy(f*1e-6, abs(1/R), lw=2, label="measured with Agilent", color='b')
semilogy(T[:,0]*1e-6, 10**(T[:,1]/20), lw=2, label="measured with FieldFox", color='m')
grid(which='both')
xticks(arange(20, 31))
legend(loc='best')
ylabel('return loss')



subplot(212)
semilogy(f*1e-6, f/f*50, lw=1.5, label="", color='0.7')
semilogy(f*1e-6, abs(Z), lw=2, label="imepdance", color='r')
grid(which='both')
xticks(arange(20, 31))
ylabel('Abs. input impedance [Ohm]')
xlabel("Frequency [MHz]")

savefig("../figures/24MHz_RFchar.pdf", transparent=True)
show()
